pub trait Spanned {
// Required method
fn span(&self) -> Range;
}Expand description
A syntax node that can report a source span.
pub trait Spanned {
// Required method
fn span(&self) -> Range;
}A syntax node that can report a source span.